@@ -10,7 +10,7 @@
 $giorni = array("Domenica","Lunedi","Martedi","Mercoledi","Giovedi","Venerdi","Sabato");
 $mesi = array("Gennaio","Febbraio","Marzo","Aprile","Maggio","Giugno","Luglio","Agosto","Settembre","Ottobre","Novembre","Dicembre");
 
-//su alcune piattaforme  necessario...
+//su alcune piattaforme e' necessario...
 $GLOBALS['giorni'] = $giorni;
 $GLOBALS['mesi'] = $mesi;
 
@@ -18,7 +18,7 @@ define("_CHARSET","ISO-8859-1");
 define("_CERCA","Cerca");
 define("_CERCASTR","Cerca parola in:");
 define("_ALLSITE","Tutto il sito");
-define("_POSTATO","Postato ");
+define("_POSTATO","Pubblicato ");
 define("_LETTO","letto ");
 define("_VOLTE","volte");
 define("_LEGGITUTTO","Leggi tutto");
@@ -192,7 +192,7 @@ define("_FP_NUOVOSONDAGGIO","Nuovo sondaggio");
 define("_FP_OPZIONE","Opzione");
 define("_FP_ARCHIVEOK","Il sondaggio  stato archiviato!");
 define("_FP_DELETEOK1","Il sondaggio chiuso il");
-define("_FP_DELETEOK2"," stato eliminato!");
+define("_FP_DELETEOK2","E' stato eliminato!");
 define("_FP_CHIUSO","Chiuso");
 define("_FP_ELIMINA","Elimina");
 define("_FP_NONEOLD","Nessun sondaggio archiviato.");
@@ -260,7 +260,7 @@ define("_GOTOTHEPAGE","Vai alla pagina");
 define("_GOTOTHEFIRSTPAGE","Vai alla prima pagina");
 define("_GOTOTHELASTPAGE","Vai all'ultima pagina");
 define("_GOTOTHEPREVIOUSPAGE","Vai alla pagina precedente");
-define("_GOTOTHENEXTPAGE","Vai alla pagina sussessiva");
+define("_GOTOTHENEXTPAGE","Vai alla pagina successiva");
 define("_EDITTOPIC","Modifica il topic");
 define("_DELETETOPIC","Elimina il topic");
 define("_MOVETOPIC","Sposta il topic");
@@ -353,7 +353,7 @@ define("_TOPICLOCKED","Il topic sar bloccato");
 define("_TOPICUNLOCKED","Il topic sar sbloccato");
 define("_VIEWFFLOG","Visualizza il log di Flatforum");
 define("_VIEWFFERRORLOG","Visualizza il log degli errori di Flatforum");
-define("_ISSPAM"," considerato spam");
+define("_ISSPAM","E' considerato spam");
 define("_LASTEDITBY","Ultima modifica di");
 
 //2.7
@@ -428,4 +428,42 @@ define("_CHANGESECTTYPE","Cambia tipo sezione");
 define("_EXEC","Esegui");
 define("_CHOOSEACTION","Scegli azione");
 define("_MANAGESECTNOTE","Modifica il testo della sezione corrente o scegli un'opzione di amministrazione nell'elenco a destra");
+define("_FNPRESENTATION","Presentazione");
+
+// 2.7.1
+define("_NEWPWDSTRING","Recupera password");
+define("_NEWPWDFORM","<b>Richiedi una nuova password</b>:<br /><br />Inserisci il tuo indirizzo
+	di posta elettronica; ti verr&agrave; immediatamente spedita una e-mail contenente le
+	istruzioni su come convalidare la tua richiesta di recupero della password.<br />
+	L'e-mail inviata conterr&agrave; inoltre la tua NUOVA password.<br />
+	Presta bene attenzione al fatto che non sarai in grado di utilizzare la nuova password
+	finch&eacute; non avrai convalidato la richiesta; quindi, in mancanza di convalida,
+	rester&agrave; valida la vecchia password.");
+define("_NEWPWDFROM","Richiesta nuova password da:");
+define("_NEWPWDMAIL","Ciao __USERNAME__,\n
+questa e-mail ti  stata inviata da __SITEURL__ in seguito ad una
+richiesta di recupero password.\n
+Se non hai fatto tu la richiesta di recupero, ignora questa e-mail: la tua
+vecchia password rimarr invariata. Per evitare errori o abusi,
+puoi convalidare soltanto tu la richiesta tramite questa e-mail.\n
+*** Continua solo se vuoi recuperare la password ***\n
+------------------------------------------------
+ISTRUZIONI PER CONVALIDARE LA RICHIESTA
+------------------------------------------------\n
+Per convalidare la tua richiesta, clicca sul link fornito qui sotto:\n
+__URLCONFIRMPASSWORDCHANGE__\n
+(alcuni programmi di posta elettronica non permettono di cliccare il
+link sopra riportato, in tal caso copia ed incolla il link completo nella
+barra degli indirizzi del tuo browser).\n
+Una volta che il processo di attivazione/convalida sar completato,
+potrai collegarti al sito utilizzando la tua nuova password che trovi qui
+sotto. Potrai modificare questa password in ogni momento, utilizzando le
+funzioni del tuo pannello di controllo.\n
+------------------------------------------------
+LA TUA NUOVA PASSWORD (DOPO LA CONVALIDA)
+------------------------------------------------\n
+Usa la nuova password solo dopo averla convalidata col link soprastante.\n
+Dopo la convalida, la tua nuova password sar: __REGCODE__\n
+Tieni la password in un luogo sicuro e lontano da occhi indiscreti. Se
+desideri cambiarla, usa il pannello di controllo presente nel sito.");
 ?>
\ No newline at end of file
