@@ -55,7 +55,15 @@ if (isset($_GET['action'])){
 			if (!check_var($regcode,"digit")) die("The registration code is not valid!");
 			activate_user($user,$regcode);
 		break;
-	}
+		case "passwordlost":
+			password_lost();
+		break;
+		case "newpwd":
+			$user    = trim(getparam("user", PAR_GET, SAN_FLAT));
+			$regcode = trim(getparam("regcode", PAR_GET, SAN_FLAT));
+			activate_newpwd($user, $regcode);
+		break;
+      }
 }
 else if (isset($_POST['action'])){
 	$action = getparam("action",PAR_POST,SAN_FLAT);
@@ -69,6 +77,9 @@ else if (isset($_POST['action'])){
 	case "saveprofile":
 		save_profile();
 	break;
+	case "sendnewpassword":
+		send_new_password();
+	break;
 	}
 }
 else  {
@@ -288,12 +299,14 @@ function view_profile($user=""){
 		<tr>
 		<td width="30%" style="<?=$style1?>"><b><?=_FNOME?>:</b></td>
 		<td style="<?=$style2?>"><?=$profile['name']?></td>
-		</tr>
-		<tr>
-		<td style="<?=$style1?>"><b><?=_FEMAIL?>:</b></td>
-		<td style="<?=$style2?>"><a href="mailto:<?=email_mask($profile['mail'])?>"><?=str_replace("%20"," ",email_mask($profile['mail']))?></a></td>
-		</tr>
-		<tr>
+		</tr><?
+		if($profile['hiddenmail']=="0" OR is_admin() OR $myforum==$user) {
+			?><tr>
+			<td style="<?=$style1?>"><b><?=_FEMAIL?>:</b></td>
+			<td style="<?=$style2?>"><a href="mailto:<?=email_mask($profile['mail'])?>"><?=str_replace("%20"," ",email_mask($profile['mail']))?></a></td>
+			</tr><?
+		}
+		?><tr>
 		<td style="<?=$style1?>"><b><?=_FHOME?>:</b></td>
 		<td style="<?=$style2?>"><?
 		if (trim($profile['homepage'])!=""){
@@ -314,6 +327,27 @@ function view_profile($user=""){
 		?></td>
 		</tr>
 		<tr>
+		<td style="<?=$style1?>"><b>Jabber / Google Talk:</b></td>
+		<td style="<?=$style2?>"><?=$profile['jabber']?></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><b>Skype:</b></td>
+		<td style="<?=$style2?>"><?=$profile['skype']?></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><b>ICQ:</b></td>
+		<td style="<?=$style2?>"><?=$profile['icq']?></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><b>MSN:</b></td>
+		<td style="<?=$style2?>"><?=$profile['msn']?></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><b><?=_FNPRESENTATION; ?>:</b></td>
+		<td style="<?=$style2?>"><? echo tag2html($profile['presentation'],"forum"); ?></td>
+		</tr>
+		<tr>
+		<tr>
 		<td style="<?=$style1?>"><b><?=_LEVEL?>:</b></td>
 		<td style="<?=$style2?>"><?=$profile['level']?></td>
 		</tr>
@@ -465,12 +499,12 @@ function edit_profile($user=""){
  */
 function save_profile(){
 
-	//controllo se  possibile registrarsi sulo sito
+	//controllo se e' possibile registrarsi sulo sito
 	if (isset($_GET['reguser']) or isset($_POST['reguser']) or isset($_COOKIE['reguser'])) die(_NONPUOI);
 	global $reguser;
 	if ($reguser!="1" and $reguser!="2"){
 		//posso continuare solo se sto modificando il mio profilo.
-		//oppure se sto modificando il profilo di un altro in qualit di amministratore
+		//oppure se sto modificando il profilo di un altro in qualita' di amministratore
 		$nome="";
 		$myforum="";
 		$nome=getparam("user",PAR_POST,SAN_FLAT);
@@ -511,6 +545,16 @@ function save_profile(){
 		else $prof="";
 	if(isset($_POST['prov'])) $prov=$_POST['prov'];
 		else $prov="";
+	if (isset($_POST['fnjabber'])) $jabber= $_POST['fnjabber'];
+		else $jabber="";
+	if (isset($_POST['fnskype'])) $skype= $_POST['fnskype'];
+		else $skype="";
+	if (isset($_POST['fnicq'])) $icq= $_POST['fnicq'];
+		else $icq="";
+	if (isset($_POST['fnmsn'])) $msn= $_POST['fnmsn'];
+		else $msn="";
+	if (isset($_POST['fnpresentation'])) $presentation= $_POST['fnpresentation'];
+		else $presentation="";
 	if(isset($_POST['ava'])) $ava=$_POST['ava'];
 		else $ava="";
 	if(isset($_POST['url_avatar']) AND eregi("(jpg|jpeg|png|gif)",get_file_extension($_POST['url_avatar'])) )
@@ -544,6 +588,29 @@ function save_profile(){
 	$prof=str_replace(chr(10),"",str_replace(chr(13),"",$prof));
 	$prov=str_replace("\r","",str_replace("\n","",$prov));
 	$prov=str_replace(chr(10),"",str_replace(chr(13),"",$prov));
+
+	$jabber=str_replace("\r","",str_replace("\n","",$jabber));
+	$jabber=str_replace(chr(10),"",str_replace(chr(13),"",$jabber));
+	$jabber=str_replace("\r","",str_replace("\n","",$jabber));
+	$jabber=str_replace(chr(10),"",str_replace(chr(13),"",$jabber));
+	$skype=str_replace("\r","",str_replace("\n","",$skype));
+	$skype=str_replace(chr(10),"",str_replace(chr(13),"",$skype));
+	$skype=str_replace("\r","",str_replace("\n","",$skype));
+	$skype=str_replace(chr(10),"",str_replace(chr(13),"",$skype));
+	$icq=str_replace("\r","",str_replace("\n","",$icq));
+	$icq=str_replace(chr(10),"",str_replace(chr(13),"",$icq));
+	$icq=str_replace("\r","",str_replace("\n","",$icq));
+	$icq=str_replace(chr(10),"",str_replace(chr(13),"",$icq));
+	$msn=str_replace("\r","",str_replace("\n","",$msn));
+	$msn=str_replace(chr(10),"",str_replace(chr(13),"",$msn));
+	$msn=str_replace("\r","",str_replace("\n","",$msn));
+	$msn=str_replace(chr(10),"",str_replace(chr(13),"",$msn));
+	
+	$presentation=str_replace("\r","",str_replace("\n","",$presentation));
+	$presentation=str_replace(chr(10),"",str_replace(chr(13),"",$presentation));
+	$presentation=str_replace("\r","",str_replace("\n","",$presentation));
+	$presentation=str_replace(chr(10),"",str_replace(chr(13),"",$presentation));
+	
 	$ava=str_replace("\r","",str_replace("\n","",$ava));
 	$ava=str_replace(chr(10),"",str_replace(chr(13),"",$ava));
 	$url_avatar=str_replace("\r","",str_replace("\n","",$url_avatar));
@@ -558,7 +625,7 @@ function save_profile(){
 	if($level>10)
 		$level=10;
 	// io posso modificare il mio ma solo se mantengo il livello!!!
-	// l'amministratore pu modificare tutti i profili
+	// l'amministratore puo' modificare tutti i profili
 	if((($nome==$myforum) and (getlevel($nome,"home")==$level) and versecid($nome)) or ((getlevel($myforum,"home")==10) and versecid($myforum))){
 	
 		?><br /><br />
@@ -627,9 +694,15 @@ function save_profile(){
 		$data['from'] = $prov;
 		$data['avatar'] = $ava;
 		$data['sign'] = $firma;
+		$data['jabber']=$jabber;
+		$data['skype']=$skype;
+		$data['icq']=$icq;
+		$data['msn']=$msn;
+		$data['presentation']=$presentation;
 		$data['level'] = $level;
 		
 		
+		
 		save_user_profile($nome,$data);
 		fnlog("Saveprofile", getparam("REMOTE_ADDR",PAR_SERVER, SAN_FLAT)."||".$myforum."||User $myforum changed his profile.");?>
 		<div align="center">
@@ -650,7 +723,7 @@ function save_profile(){
 
 
 function reguser(){
-	//controllo se  possibile registrarsi sulo sito
+	//controllo se e' possibile registrarsi sulo sito
 	if (isset($_GET['reguser']) or isset($_POST['reguser']) or isset($_COOKIE['reguser'])) die(_NONPUOI);
 	global $reguser,$sitename;
 	if ($reguser!="1" and $reguser!="2") die(_NONPUOI);
@@ -812,7 +885,7 @@ function reguser(){
 
 			if ($reguser==2){
 				
-				//controllo che la mail non sia gi stata usata per la registrazione di un altro utente
+				//controllo che la mail non sia gia' stata usata per la registrazione di un altro utente
 				if (in_array($email,list_reg_emails()) or in_array($email,list_reg_emails(1))){
 					echo "<div style=\"text-align: center;\">"._THEMAIL." $email "._MAILUSED;
 					echo "<br /><br /><a href=\"javascript:history.back()\">&lt;&lt;"._INDIETRO."</a></div>";
@@ -821,15 +894,15 @@ function reguser(){
 				
 				//genero il codice di attivazione
 				$data['regcode'] = mt_rand(1,99999999);
-				//devo controllare la validit della mail
-				//se non  valida interrompo e permetto di tornare indietro
+				//devo controllare la validita' della mail
+				//se non e' valida interrompo e permetto di tornare indietro
 				if (!check_mail($email)){
 					echo "<div style=\"text-align: center;\"><b>"._ERREMAIL."!</b>";
 					echo "<br /><br /><a href=\"javascript:history.back();\">&lt;&lt; "._INDIETRO."</a></div>";
 					die();
 				}
 				
-				//se l'e-mail  spammosa blocco tutto!
+				//se l'e-mail e' spammosa blocco tutto!
 				if (is_spam($email,"emails")){
 					echo "<b>"._ERREMAIL."</b> ("._ISSPAM.")";
 					$addr = getparam("REMOTE_ADDR",PAR_SERVER, SAN_FLAT);
@@ -854,9 +927,10 @@ function reguser(){
 				
 				$message = _IST_REG_MAIL."\n\n$url";
 				
-				if (mail($email, _COMP_REG_MAIL." $sitename", $message,"FROM: $sitename <noreply@noreply>\n")){
+				if (@mail($email, _COMP_REG_MAIL." $sitename", $message,"FROM: $sitename <noreply@noreply>\r\nX-Mailer: Flatnuke on PHP/".phpversion())){
 					echo _COMP_REG." <b>$email</b>";
 					echo "<br />"._COMP_REG2;
+					fnlog("Registration", $addr."||".$myforum."||Activation mail sent for $nome.");
 				}
 				else {
 					echo _ACTIVATIONMAILNOTSENT;
@@ -1048,6 +1122,22 @@ function edit_user_interface($user,$action){
 		<td style="<?=$style2?>"><input name="prov" type="text" id="prov" value="<?=$profile['from']?>" /></td>
 		</tr>
 		<tr>
+		<td style="<?=$style1?>"><label for="fnjabber">Jabber / Google Talk</label></td>
+		<td style="<?=$style2?>"><input name="fnjabber" type="text" id="fnjabber" value="<?=$profile['jabber']?>" /></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><label for="fnskype">Skype</label></td>
+		<td style="<?=$style2?>"><input name="fnskype" type="text" id="fnskype" value="<?=$profile['skype']?>" /></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><label for="fnicq">ICQ</label></td>
+		<td style="<?=$style2?>"><input name="fnicq" type="text" id="fnicq" value="<?=$profile['icq']?>" /></td>
+		</tr>
+		<tr>
+		<td style="<?=$style1?>"><label for="fnmsn">MSN</label></td>
+		<td style="<?=$style2?>"><input name="fnmsn" type="text" id="fnmsn" value="<?=$profile['msn']?>" /></td>
+		</tr>
+		<tr>
 		<td style="<?=$style1?>"><label for="ava"><?=_FAVAT?></label></td>
 		<td style="<?=$style2?>"><?
 			// set path for local/remote images
@@ -1098,6 +1188,14 @@ function edit_user_interface($user,$action){
 		$profile['sign'] = chop($profile['sign']);
 		?><td style="<?=$style2?>"><textarea name="firma" id="firma" rows="5" cols="23"><?=stripslashes($profile['sign']);?></textarea></td>
 		</tr>
+		
+		<tr>
+		<td style="<?=$style1?>"><label for="fnpresentation"><?=_FNPRESENTATION?></label></td><?
+// 		$profile['presentation'] = str_replace("<br />","\n",$profile['presentation']);
+// 		$profile['presentation'] = chop($profile['presentation']);
+		?><td style="<?=$style2?>"><textarea name="fnpresentation" id="fnpresentation" rows="5" cols="23"><?=stripslashes($profile['presentation']);?></textarea></td>
+		</tr>
+		
 		<tr>
 		<? // admins can manage user level
 		if(is_admin()){
@@ -1171,4 +1269,121 @@ function activate_user($user,$regcode){
 	}
 }
 
+
+/**
+ * Interfaccia richiesta nuova password
+ *
+ * La funzione visualizza tutte le informazioni necessarie
+ * all'utente per richiedere una nuova password.
+ * 
+ * @author Marco Segato <segatom@users.sourceforge.net>
+ * @since 2.7.1
+ */
+function password_lost() {
+	?><div style='text-align:justify;padding:1em;'><?
+	echo _NEWPWDFORM;
+	?></div>
+	<div style="text-align:center;padding:1em;">
+	<form action="index.php?mod=none_Login" method="post">
+		<input type="hidden" name="action" value="sendnewpassword" />
+		<label for="email"><?=_FEMAIL?>: </label><input name="email" type="text" id="email" />
+		<input type="submit" />
+	</form>
+	</div><?
+}
+
+
+/**
+ * Invio nuova password
+ *
+ * La funzione permette di inviare una nuova password
+ * all'utente che ne ha fatto richiesta; viene spedita
+ * una email che contiene l'URL da visitare per attivare
+ * il cambio di password.
+ * 
+ * @author Marco Segato <segatom@users.sourceforge.net>
+ * @since 2.7.1
+ */
+function send_new_password() {
+	// security checks
+	$email = trim(getparam("email", PAR_POST, SAN_FLAT));
+	$addr  = getparam("REMOTE_ADDR",PAR_SERVER, SAN_FLAT);
+	global $sitename;
+	
+	// get the list of all users' emails
+	$emails_active = list_users_emails();
+	//echo "<pre>"; print_r($emails_active); echo "</pre>"; //-> TEST
+	echo "<div style='text-align:justify;padding:1em;'>";
+	
+	if(!in_array($email, $emails_active)) {
+		echo _ERREMAIL;	// provided address doesn't exist
+	} else {
+		$user_arr  = array_keys($emails_active, $email);
+		$user      = $user_arr[0];	// username
+		$user_data = load_user_profile($user);	// user profile
+		// create the new password for registration and save it
+		$rand_pwd = rand(10000000, 99999999);
+		$user_data['regcode'] = $rand_pwd;
+		save_user_profile($user, $user_data);
+		// try to send activation code to the user
+		$url = "http://".$_SERVER['SERVER_NAME'].$_SERVER['SCRIPT_NAME']."?mod=none_Login&action=newpwd&user=$user&regcode=$rand_pwd";
+		//echo "<p><a href=\"$url\">$url</a></p>"; //-> TEST
+		$message = _NEWPWDMAIL;
+		$message = str_replace("__USERNAME__", $user, $message);
+		$message = str_replace("__SITEURL__", "http://".$_SERVER['SERVER_NAME'].$_SERVER['SCRIPT_NAME'], $message);
+		$message = str_replace("__URLCONFIRMPASSWORDCHANGE__", $url, $message);
+		$message = str_replace("__REGCODE__", $rand_pwd, $message);
+		if (@mail($email, _NEWPWDFROM." $sitename", $message,"FROM: $sitename <noreply@noreply>\r\nX-Mailer: Flatnuke on PHP/".phpversion())){
+			echo _COMP_REG." <b>$email</b>";
+			echo "<br />"._COMP_REG2;
+			fnlog("New password", $addr."||||Activation mail for a new password sent to user '$user'.");
+		} else {
+			echo _ACTIVATIONMAILNOTSENT;
+			fnlog("New password", $addr."||||Activation mail for a new password not sent to user '$user'.");
+		}
+	}
+	echo "</div>";
+}
+
+
+/**
+ * Attivazione nuova password richiesta
+ *
+ * La funzione permette di attivare la nuova password
+ * inviata via email all'utente che ne ha fatto richiesta.
+ * 
+ * @author Marco Segato <segatom@users.sourceforge.net>
+ * @since 2.7.1
+ *
+ * @param string $user    Nome utente
+ * @param string $regcode Codice di attivazione
+ */
+function activate_newpwd($user, $regcode) {
+	// security checks
+	$user    = getparam($user,PAR_NULL,SAN_FLAT);
+	$regcode = getparam($regcode,PAR_NULL,SAN_FLAT);
+	$addr    = getparam("REMOTE_ADDR",PAR_SERVER, SAN_FLAT);
+	
+	echo "<div style='text-align:center;padding:1em;'>";
+	if (file_exists(get_fn_dir("users")."/$user.php") AND is_alphanumeric($user)) {
+		$userdata = load_user_profile($user);
+		if ($regcode==$userdata['regcode'] AND check_var($regcode,"digit")) {
+			// build new password
+			$userdata['password'] = md5($regcode);
+			// once activated, reset regcode
+			$userdata['regcode']  = 0;
+			save_user_profile($user, $userdata);
+			fnlog("New password","$addr||||User '$user' succesfully activated the new password.");
+		} else {
+			fnlog("New password","$addr||||Regcode of the user '$user' is not matching.");
+		}
+	} else {
+		fnlog("New password","$addr||||Tried to activate a new password for unexistant '$user' user.");
+	}
+	// reset cookies
+	logout();
+	header("Location: index.php?mod=none_Login");
+	die();
+}
+
 ?>
\ No newline at end of file
