@@ -1,4 +1,4 @@
-<?
+<?php
 
 /**
  * File delle funzioni condivise tra il forum e il core di FlatNuke
@@ -21,7 +21,7 @@
  * @return constant Versione di Flatnuke
  */
 function get_fn_version(){
-   define("FN_VERSION", "2.7");
+   define("FN_VERSION", "2.7.1");
    return FN_VERSION;
 }
 
@@ -167,7 +167,7 @@ function getpass($user) {
  * Applica un semaforo ad un file
  *
  * Applica un semaforo al file passato come parametro, impedendo qualsiasi
- * azione fintanto che non sar spento con la chiave MD5 corretta.
+ * azione fintanto che non sara' spento con la chiave MD5 corretta.
  * NB: la gestione dei semafori deve essere supportata dal proprio webserver.
  *
  * @author Simone Vellei <simone_vellei@users.sourceforge.net>
@@ -415,7 +415,7 @@ function getlevel($admin, $from){
 
 
 /**
- * Controllo sulla validit di una stringa alfanumerica
+ * Controllo sulla validita' di una stringa alfanumerica
  *
  * Esegue un controllo sulla stringa passata come parametro, verificando che
  * contenga unicamente caratteri oppure numeri, secondo lo standard UNIX.
@@ -497,7 +497,7 @@ function rawurlencodepath($path){
  * @since 2.5.8
  *
  * @param string $target Directory da eliminare
- * @param boolean $verbose Indica se attivare o meno la modalit 'verbose' (disattivata di default)
+ * @param boolean $verbose Indica se attivare o meno la modalita' 'verbose' (disattivata di default)
  * @return boolean Vero o Falso
 */
 function rmdirr($target, $verbose=FALSE) {
@@ -548,9 +548,9 @@ function rmdirr($target, $verbose=FALSE) {
  * @param string $mode    modo di scrittura da passare alla funzione fopen
  * @param array  $options lista delle opzioni di scrittura
  * Le opzioni possono essere:
- * 	- nonull: la stringa da scrivere non pu essere vuota
- * 	- nophp:  il testo non pu contenere codice php
- * 	- nohtml: il testo non pu contenere codice html
+ * 	- nonull: la stringa da scrivere non puo' essere vuota
+ * 	- nophp:  il testo non puo' contenere codice php
+ * 	- nohtml: il testo non puo' contenere codice html
  */
 function fnwrite($file, $text, $mode, $options=array()) {
 	$file = getparam($file, PAR_NULL, SAN_NULL);
@@ -596,7 +596,7 @@ function fnwrite($file, $text, $mode, $options=array()) {
 		}
 
 	} else {
-		fnlog("Write", $addr."||".get_username()."||Null backup file!!");
+		//fnlog("Write", $addr."||".get_username()."||Null \"$file.bak\" backup file!!");	// uncomment if you experience problems with filesystem
 		unlink($file."bak");
 	}
 
@@ -665,11 +665,11 @@ function email_mask($email_address) {
 /**
  * Controlla il percorso di file che gli viene passato come parametro.
  *
- * Questa funzione verifica la validit del percorso passato come parametro. Innanzitutto viene
+ * Questa funzione verifica la validita' del percorso passato come parametro. Innanzitutto viene
  * verificata la presenza di caratteri potenzialmente pericolosi.
  * Con il secondo parametro si indica eventualmente la cartella all'interno della quale deve trovarsi il file
  * (o sue sottocartelle).
- * Con il terzo parametro si indica se il file pu avere estensione "php*"
+ * Con il terzo parametro si indica se il file puo' avere estensione "php*"
  * Se il percorso rispetta tutte le condizioni la funzione restituisce TRUE,
  * in caso contrario restituisce FALSE.
  *
@@ -733,7 +733,7 @@ function check_path($filename,$dirbase,$allow_php){
  * Sono supportati i seguenti tipi:
  * 1. digit: solo numeri
  * 2. alnum: numeri e cifre (no spazi o segni di punteggiatura)
- * 3. text (no html): restituisce true se il testo  uguale al testo restituito dalla funzione strip_tag
+ * 3. text (no html): restituisce true se il testo e' uguale al testo restituito dalla funzione strip_tag
  *                    (ovvero non sono presenti tag html/php nella stringa)
  * 4. boolean: i valori validi sono "1", "0", "true", "false", "on" e "off" (case insensitive)
  *
@@ -778,17 +778,17 @@ include_once("include/php_filters/sanitize.php");
 
 
 /**
- * Questa funzione restituisce TRUE se l'indirizzo passato come parametro  incluso nella lista degli ip bloccati.
- * FALSE se l'indirizzo ip  ok. L'elenco degli ip bloccati  incluso nel file include/blacklists/ipblacklist.php
+ * Questa funzione restituisce TRUE se l'indirizzo passato come parametro e' incluso nella lista degli ip bloccati.
+ * FALSE se l'indirizzo ip e' ok. L'elenco degli ip bloccati e' incluso nel file include/blacklists/ipblacklist.php
  * 
- * Restituisce TRUE se l'indirizzo passato come parametro  inserito nella blacklist, 
+ * Restituisce TRUE se l'indirizzo passato come parametro e' inserito nella blacklist, 
  * FALSE in caso contrario.
  * 
  * @author Aldo Boccacci
  * @since 2.6
  *
  * @param string $ip l'indirizzo ip da verificare.
- * @return TRUE se l'indirizzo  vietato, FALSE in caso contrario
+ * @return TRUE se l'indirizzo e' vietato, FALSE in caso contrario
  */
 function is_blocked_ip($ip){
 	if (trim($ip)=="") return FALSE;
@@ -827,13 +827,17 @@ function is_blocked_ip($ip){
  *
  * @param string $string la stringa da controllare
  * @param string $spamfile il nome senza estensione del file contenente i criteri di riconiscimento
- * @return TRUE se la stringa  vietata, FALSE in caso contrario
+ * @return TRUE se la stringa e' vietata, FALSE in caso contrario
  */
 function is_spam($string,$spamfile){
 	if (!check_path($spamfile,"","false")) die("spam file path is not valid! ".basename(__FILE__).": ".__LINE__);
 	if (trim($string)=="") return FALSE;
 	// load spam file
 	if (!file_exists("include/blacklists/$spamfile.php")){
+		return FALSE;
+	}
+	// limit the number of the links to max 3
+	if (substr_count($string, "http://")>3 OR substr_count($string, "https://")>3 OR substr_count($string, "ftp://")>3){
 		return TRUE;
 	}
 	$blstring = get_file("include/blacklists/$spamfile.php");
@@ -844,7 +848,7 @@ function is_spam($string,$spamfile){
 	foreach ($wordsarray as $item){
 		if (eregi("^#",trim($item))) continue;
 		if (trim($item)=="") continue;
-		if (preg_match("/\b$item\b/i",$string)) {
+		if (preg_match("/\b$item\b/i",$string) OR eregi($item, $string)) {
 			$ip = getparam("REMOTE_ADDR",PAR_SERVER,SAN_FLAT);
 			fnlog("Spam", "$ip||".get_username()."||Spamfilter blocked the regexp \"$item\".");
 			return TRUE;
